@@ -4,10 +4,15 @@ from datetime import datetime
 import warnings
 
 class SchemaError(ValueError):
-    """errors relating to an invalid schema passed to validate"""
+    """
+    errors encountered in processing a schema (subclass of :class:`ValueError`)
+    """
 
 class ValidationError(ValueError):
-    """validation errors encountered during validate"""
+    """
+    validation errors encountered during validation (subclass of
+    :class:`ValueError`)
+    """
 
 def _generate_datetime_validator(format_option, dateformat_string):
     def validate_format_datetime(validator, fieldname, value, format_option):
@@ -40,7 +45,12 @@ DEFAULT_FORMAT_VALIDATORS = {
 
 class SchemaValidator(object):
     '''
-    Validator based on JSON Schema Proposal 2nd Draft.
+    Validator largely based upon the JSON Schema proposal but useful for
+    validating arbitrary python data structures.
+
+    :param format_validators: optional dictionary of custom format validators
+    :param required_by_default: defaults to True, set to False to make 
+        ``required`` schema attribute False by default.
     '''
 
     def __init__(self, format_validators=None, required_by_default=True):
@@ -95,8 +105,7 @@ class SchemaValidator(object):
             value = x[fieldname]
         except KeyError:
             fieldexists = False
-        finally:
-            value = x.get(fieldname)
+            value = None
 
         if fieldtype and fieldexists:
             if isinstance(fieldtype, (list, tuple)):
@@ -137,7 +146,7 @@ class SchemaValidator(object):
             value = x.get(fieldname)
             if isinstance(value, dict):
                 if isinstance(properties, dict):
-                    for eachProp in properties.keys():
+                    for eachProp in properties:
                         self.__validate(eachProp, value,
                                         properties.get(eachProp))
                 else:
@@ -152,7 +161,7 @@ class SchemaValidator(object):
             value = x.get(fieldname)
             if isinstance(value, (list, tuple)):
                 if isinstance(items, (list, tuple)):
-                    if not 'additionalItems' in schema.keys() and len(items) != len(value):
+                    if not 'additionalItems' in schema and len(items) != len(value):
                         self._error("Length of list %(value)r for field '%(fieldname)s' is not equal to length of schema list",
                                     value, fieldname)
                     else:
@@ -175,7 +184,7 @@ class SchemaValidator(object):
         Validates that the given field is present if required is True
         '''
         # Make sure the field is present
-        if fieldname not in x.keys() and required:
+        if fieldname not in x and required:
             self._error("Required field '%(fieldname)s' is missing",
                         None, fieldname)
 
@@ -207,7 +216,7 @@ class SchemaValidator(object):
             return
 
         if isinstance(additionalItems, bool):
-            if additionalItems or 'items' not in schema.keys():
+            if additionalItems or 'items' not in schema:
                 return
             elif len(value) != len(schema['items']):
                 #print locals(), value, len(value), len(schema['items'])
@@ -236,7 +245,7 @@ class SchemaValidator(object):
                 properties = {}
             if value is None:
                 value = {}
-            for eachProperty in value.keys():
+            for eachProperty in value:
                 if eachProperty not in properties:
                     # If additionalProperties is the boolean value False
                     # then we don't accept any additional properties.
@@ -258,9 +267,26 @@ class SchemaValidator(object):
 
     def validate_dependencies(self, x, fieldname, schema, dependencies=None):
         if x.get(fieldname) is not None:
-            if x.get(dependencies) is None:
-                self._error("Field '%(dependencies)s' is required by field '%(fieldname)s'",
-                            None, fieldname, dependencies=dependencies)
+
+            # handle cases where dependencies is a string or list of strings
+            if isinstance(dependencies, basestring):
+                dependencies = [dependencies]
+            if isinstance(dependencies, (list, tuple)):
+                for dependency in dependencies:
+                    if dependency not in x:
+                        self._error("Field '%(dependency)s' is required by field '%(fieldname)s'",
+                            None, fieldname, dependency=dependency)
+            elif isinstance(dependencies, dict):
+                # NOTE: the version 3 spec is really unclear on what this means
+                # based on the meta-schema I'm assuming that it should check
+                # that if a key exists, the appropriate value exists
+                for k,v in dependencies.iteritems():
+                    if k in x and v not in x:
+                        self._error("Field '%(v)s' is required by field '%(k)s'",
+                                    None, fieldname, k=k,v=v)
+            else:
+                raise SchemaError("'dependencies' must be a string, "
+                                  "list of strings, or dict")
 
     def validate_minimum(self, x, fieldname, schema, minimum=None):
         '''
